/* Bluefish HTML Editor
 * images.h - image stuff prototypes
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __IMAGES_H_
#define __IMAGES_H_

#include <glib.h>
#include <gtk/gtkwidget.h>

void image_insert_dialog_cb(GtkWidget * widget, gpointer data);
void image_thumbnail_dialog_cb(GtkWidget * widget, gpointer data);

#endif							/* __IMAGES_H_ */
